@@ -1,7 +1,7 @@
-package TableData::Object::Common;
+package TableData::Object::Base;
 
-our $DATE = '2015-09-15'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2015-10-29'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010;
 use strict;
@@ -60,11 +60,11 @@ __END__
 
 =head1 NAME
 
-TableData::Object::Common - Base class for TableData::Object::*
+TableData::Object::Base - Base class for TableData::Object::*
 
 =head1 VERSION
 
-This document describes version 0.03 of TableData::Object::Common (from Perl distribution TableData-Object), released on 2015-09-15.
+This document describes version 0.04 of TableData::Object::Base (from Perl distribution TableData-Object), released on 2015-10-29.
 
 =for Pod::Coverage .+
 
